@@ -21,15 +21,12 @@ check() {
 	   [[ "$KDUMP_POSTSCRIPT" =~ "$FENCE_KDUMP_SEND" ]] ; then
 		# add fence_kdump_send to initrd automatically
 		KDUMP_REQUIRED_PROGRAMS="$KDUMP_REQUIRED_PROGRAMS $FENCE_KDUMP_SEND"
-		# set up network (unless explicitly disabled by KDUMP_NETCONFIG)
+		# set up network
 		kdump_neednet=y
 	fi
 
 	# check if network is needed
-	if [ -z "$KDUMP_NETCONFIG" ]; then
-		# network explicitly disabled in configuration
-		kdump_neednet=
-	elif [ "${KDUMP_NETCONFIG%:force}" != "$KDUMP_NETCONFIG" ]; then
+	if [ "${KDUMP_NETCONFIG%:force}" != "$KDUMP_NETCONFIG" ]; then
 		# always set up network
 		kdump_neednet=y
 	else
@@ -62,7 +59,7 @@ kdump_ip_set_explicitly() {
 	local opts
 
 	if [ "$KDUMP_FADUMP" = true ]; then
-		_opts="`cat /proc/cmdline`"
+		_opts="$FADUMP_COMMANDLINE_APPEND"
 	else
 		_opts="$KDUMP_COMMANDLINE $KDUMP_COMMANDLINE_APPEND"
 	fi
@@ -213,6 +210,16 @@ install() {
 		# is resolved first to install directly the target file if it is a symlink.
 		local resolv=$(realpath /etc/resolv.conf)
 		inst_simple "$resolv" /etc/resolv.conf
+
+		# for static or auto6 network config mode, prevent NM from
+		# replacing the installed resolv.conf with an empty one
+		case "$kdump_net_mode" in
+			static|auto6)
+				mkdir -p $initdir/etc/NetworkManager/conf.d
+				echo -e "[main]\ndns=none" > $initdir/etc/NetworkManager/conf.d/99kdump.conf
+				;;
+		esac
+
 		inst_simple /etc/hosts
 		# set up hardware interfaces
 		kdump_setup_hwif "${initdir}"
