@@ -97,6 +97,8 @@ function build_kdump_commandline()
             remove_from_commandline \
                 'root|resume|crashkernel|splash|mem|BOOT_IMAGE|showopts|zfcp\.allow_lun_scan|hugepages|acpi_no_memhotplug|cgroup_disable|unknown_nmi_panic|rd\.udev\.children-max' \
                 < /proc/cmdline)
+
+	[[ -e /proc/xen ]] && KDUMP_CPUS=1	# makedumpfile does not support --num-threads on XEN
         if [ ${KDUMP_CPUS:-1} -ne 0 ] ; then
             nr_cpus="nr_cpus=${KDUMP_CPUS:-1}"
         fi
@@ -118,13 +120,6 @@ function build_kdump_commandline()
 	    commandline="$commandline zfcp.allow_lun_scan=0"
 	    ;;
         esac
-
-        # Xen does not include the kernel release in VMCOREINFO_XEN
-        # so we have to pass it via the command line
-        if [[ $(uname -r) =~ -xen$ ]] ; then
-            kernelrelease=$(uname -r)
-            commandline="$commandline kernelversion=$kernelrelease"
-        fi
     fi
 
     commandline="$commandline $(set_serial_console)"
@@ -174,34 +169,6 @@ function fadump_enabled()
     test -f "$FADUMP_ENABLED" && test $(cat "$FADUMP_ENABLED") = "1"
 }
 
-#
-# Update the bootloader options for fadump
-function fadump_bootloader()
-{
-    case $(uname -m) in
-	ppc*) ;;
-	*) return 0 ;;
-    esac
-
-    local newstate="$1"
-
-    # check if the old configuration is still valid
-    local boot_opts=$(pbl --get-option fadump)
-    if [ "$newstate" = on ] ; then
-        # if makedumpfile not configured to filter out user pages (dump level), 
-        # or makedumpfile is not used (raw format),
-        # set fadump=nocma
-        [[ $((${KDUMP_DUMPLEVEL} & 8)) -eq 0 ]] && newstate=nocma
-        [[ ${KDUMP_DUMPFORMAT} = raw ]] && newstate=nocma
-
-        if [ "$boot_opts" != "fadump=$newstate" ] ; then
-            pbl --add-option fadump=$newstate --config
-        fi
-    elif [ -n "$boot_opts" ] ; then
-        pbl --del-option fadump --config
-    fi
-}
-
 #
 # Pass additional parameters to FADump capture kernel.
 function fadump_append_params()
@@ -225,8 +192,6 @@ function fadump_append_params()
 # Update fadump configuration
 function load_kdump_fadump()
 {
-    fadump_bootloader on
-
     if ! fadump_enabled ; then
         echo "fadump is not enabled in the kernel."
 	return 5
@@ -308,7 +273,6 @@ while [ $# -gt 0 ] ; do
     shift
 done
 
-
 if [ "$update" = yes ] ; then
     rebuild_kdumprd || exit 1
 fi
@@ -320,7 +284,13 @@ fi
 if [ "$KDUMP_FADUMP" = "true" ] ; then
     load_kdump_fadump
 else
-    fadump_bootloader off
+    read RESERVED < /sys/kernel/kexec_crash_size
+    [[ ${RESERVED} -eq 0 ]] && {
+        echo "No crashkernel memory reserved, Kdump cannot start." >&2
+	echo "Normally the crashkernel= option is handled by kdump-commandline.service" >&2
+	echo "See the status of kdump-commandline.service or man 7 kdump for details." >&2
+	exit 1
+    }
 
     # check if initrd and the kernel it was built for exist
     # return 6 if not, which is treated as success by 
