@@ -33,12 +33,14 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/utsname.h>
 #include <getopt.h>
 
 
 bool needsNetwork;
 bool needsMakedumpfile;
 long long KDUMP_CPUS, KDUMP_LUKS_MEMORY;
+char *kernel_version = NULL;
 bool m_shrink = false;
 bool debug = false;
 
@@ -298,9 +300,41 @@ SizeConstants::SizeConstants(void)
         { "USER_NET", &SizeConstants::m_user_net },
         { nullptr, nullptr }
     };
+    /* get the kernel flavour from KDUMP_KERNEL_VERSION or uname;
+       if not default, try looking for the flavour-suffixed variable,
+       falling back to the default unsuffixed variable */
+    if (!kernel_version) {
+        struct utsname uts;
+        if (uname(&uts))
+            kernel_version = uts.release;
+    }
+
+    char *flavour;
+    if (kernel_version &&
+        (flavour = strrchr(kernel_version, '-')) &&
+        *(++flavour) &&
+	    strcmp(flavour, "default")) {
+        DEBUG("Kernel flavour: %s", flavour);
+    }
+    else {
+        flavour = NULL;
+        DEBUG("Default kernel flavour");
+    }
+
     for (auto p = &vars[0]; p->name; ++p) {
-		char *val = std::getenv(p->name);
-		char *end;
+	char *val = NULL;
+        char *end;
+	if (flavour) {
+	    std::string flavoured_name(p->name);
+	    flavoured_name.append("_");
+	    flavoured_name.append(flavour);
+	    val = std::getenv(flavoured_name.c_str());
+            if (!val || !*val)
+                DEBUG("No value configured for %s, using %s", flavoured_name.c_str(), p->name);
+	}
+	if (!val || !*val)
+	    val = std::getenv(p->name);
+
         if (!val || !*val)
             throw std::runtime_error(std::string("No value configured for ") + p->name);
         this->*p->var = strtoll(val, &end, 10);
@@ -881,7 +915,7 @@ static unsigned long runtimeSize(SizeConstants const &sizes,
     }
 
     // Add memory based on CPU count
-    unsigned long cpus = 0;
+    unsigned long cpus = 0, percpu;
     if (CAN_REDUCE_CPUS) {
 	cpus = KDUMP_CPUS;
     }
@@ -893,9 +927,16 @@ static unsigned long runtimeSize(SizeConstants const &sizes,
         cpus = online + offline;
     }
     DEBUG("Total assumed CPUs: %lu", cpus);
-    cpus *= sizes.percpu_kb();
-    DEBUG("Total per-cpu requirements: %lu KiB", cpus);
-    required += cpus;
+    percpu = sizes.percpu_kb(); // kernel percpu from calibrate.conf
+    percpu += 50 * 2; // generic ~50k thread footprint (measured) * 2 for safety
+    percpu += 3 * sizes.pagesize() / 1024; // makedumpfile BUF_PARALLEL and BUF_OUT_PARALLEL
+    percpu += 128; // makedumpfile WRKMEM_PARALLEL
+    percpu += 5;   // makedumpfile ZSTD_CCTX_PARALLEL
+
+    DEBUG("Per-cpu requirements: %lu KiB", percpu);
+    percpu *= cpus;
+    DEBUG("Total per-cpu requirements: %lu KiB", percpu);
+    required += percpu;
 
     // User-space requirements
     unsigned long user = sizes.user_base_kb();
@@ -1020,6 +1061,10 @@ int main(int argc, char* argv[])
 		if (!val || !*val)
 			throw std::runtime_error("KDUMP_DUMPFORMAT not defined");
 		needsMakedumpfile = strcmp(val, "none") && strcmp(val, "raw");
+
+		val = std::getenv("KDUMP_KERNEL_VERSION");
+		if (val && *val)
+            kernel_version = val;
 	}
 	catch(std::runtime_error &e) {
 		cerr << "Error parsing config from environment variables: " << e.what() << endl;
@@ -1158,4 +1203,4 @@ int main(int argc, char* argv[])
 		exit(1);
 	}
 }
-
+// vim: set et ts=4 sw=4 :
